@@ -165,7 +165,7 @@ CREATE FUNCTION pgroonga_escape(value int8)
 
 CREATE FUNCTION pgroonga_escape(value float4)
 	RETURNS text
-	AS 'MODULE_PATHNAME', 'pgroonga_escape_float8'
+	AS 'MODULE_PATHNAME', 'pgroonga_escape_float4'
 	LANGUAGE C
 	IMMUTABLE
 	STRICT;
@@ -247,6 +247,20 @@ CREATE FUNCTION pgroonga_normalize(target text, normalizerName text)
 	IMMUTABLE
 	STRICT;
 
+CREATE FUNCTION pgroonga_tokenize(target text, VARIADIC options text[])
+	RETURNS json[]
+	AS 'MODULE_PATHNAME', 'pgroonga_tokenize'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT;
+
+CREATE FUNCTION pgroonga_vacuum()
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_vacuum'
+	LANGUAGE C
+	VOLATILE
+	STRICT;
+
 
 /* v1 */
 CREATE FUNCTION pgroonga_match_term(target text, term text)
